@@ -11,7 +11,7 @@ import re
 import os
 import qrcode
 
-__version__ = "1.0.5"
+__version__ = "1.0.7"
 
 def run_command(command):
     output, _ = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, shell=True).communicate()
@@ -32,15 +32,18 @@ def get_ssid():
         ssid = run_command(f"{airport} -I | awk '/ SSID/ {{print substr($0, index($0, $2))}}'")
         ssid = ssid.replace("\n", "")
 
-    # elif sys.platform == "linux":
-    #     ssid = run_command("nmcli -t -f ssid dev wifi")
-    #     ssid = ssid.replace("\n", "")
+    elif sys.platform == "linux":
+        if which("nmcli") is None:
+            print_error("Network Manager is required to run this program on Linux.")
+
+        ssid = run_command("nmcli -t -f active,ssid dev wifi | egrep '^yes:' | sed 's/^yes://'")
+        ssid = ssid.replace("\n", "")
 
     elif sys.platform == "win32":
         ssid = run_command("netsh wlan show interfaces | findstr SSID").replace("\r", "")
         if ssid == "":
             print_error("SSID was not found")
-        
+
         ssid = re.findall(r"[^B]SSID\s+:\s(.*)", ssid)[0]
 
     return ssid
@@ -54,12 +57,13 @@ def get_password(ssid):
         password = run_command(f"security find-generic-password -l \"{ssid}\" -D 'AirPort network password' -w")
         password = password.replace("\n", "")
 
-    # elif sys.platform == "linux":
-    #     # Check if the user is running with super user privilages
-    #     if os.geteuid() != 0:
-    #         print_error(f"You need to run '{sys.argv[0]}' as root")
+    elif sys.platform == "linux":
+        # Check if the user is running with super user privilages
+        if os.geteuid() != 0:
+            password = run_command(f"sudo nmcli -s -g 802-11-wireless-security.psk connection show '{ssid}'")
+        else:
+            password = run_command(f"nmcli -s -g 802-11-wireless-security.psk connection show '{ssid}'")
 
-        password = run_command(f"nmcli -s -g 802-11-wireless-security.psk connection show '{ssid}'")
         password = password.replace("\n", "")
 
     elif sys.platform == "win32":
